# Final Project


My project will be a **vegetable washing machine** 

## Research

Goal is to create a  kitchen appliance that can wash and dry greens and 
other vegetables via a pre set cycle both saving time (and potentially water)

## Project description 

![VMS SKETCH](../images/imagW1/VMS06.jpeg){: style="height:360px;width:720px"}

![Veg Washing Machine](../images/Finalproject/VWMSKETCHV1.jpg){: style="height:300px;width:300px"}


Here is a first cut at the base:

![Base](../images/Finalproject/2basesetup.jpg)

**There are 4 main parts to the appliance**

1. Water reservoir 

2. Main container (Wash basin)- base is designed to have a gravity fed drain

3. Lid with build in sprinkler 

4. Vegetable holding bowel that sites in the Wash basin and spins to dry 

**There are 2 Motor/pump used**

1. Water pump to move water from reservoir to sprinkler head 

2. Motor to spin Vegetable bowel 

**There are 2 potential sensors**

1. Lid sensor - stop operation if lid is open mid cycle 

2. Water level sensor to alert if reservoir is empty 

**Microcontroller usage**

1. Control sequencing of pumps / motors 

2. Interrupt operation if sensor is triggered 

3. Manage GUI 

**GUI**

1. Based display and buttons

2. Allow user to start cycle 

- Wash only

- Dry only

- Wash/dry

3. Announce alerts (ready/water empty/finished)


Here is a another view of the merging design 

![Bottom](../images/Finalproject/2baseupview.jpg)



## Align parts to Fab Academy weekly topics  


 
| Weekly topics      | Parts |
| ----------- | ----------- |
| Computer controlled cutting | Outbox / wash basin holder  |
| Electronics production | Controller, motor ESC, Sensors  |
| 3D Scanning and printing | Motor housing, water connectors, sprinkler head, sproket/chain for motor drive|
| Electronics design | sensors / controller board / Motor ESC |
| Computer controlled machining |   Controller board  |
| Embedded programming | Cycle design / User input |
| Molding and casting | Drain / Spinning plate  |
| Input devices | GUI buttons / Sensors |
| Output devices | Screen |
 


Key component breakdown 

Outer box - Plexiglass  

Wash basin holder - Plexiglass / 3d print 

Water reservoir - molding / buying 

Electronic housing - 3D print 

spinner mechanism - 3D print 

Bowel - Molding / casting 

Lid - 3D Print 

Water pump / sprinkler mechanism - 3D print / electronics 

Sensors - 1) Lid sensor 2) Water level sensor 

Controller board -

Display/Buttons 

Water connections - 3 Print or buy 


## 2D and 3D Modeling

First I set up some user parameters I will use in sizing the spinning plate and it base 

![User Parameters](../images/ImagW2/GraphicApps/40platebase1.jpg)

Now I made a round leg for the plate to sit on 

![Leg sketch](../images/ImagW2/GraphicApps/40platebase2.jpg)

To create the shape of the base I will create a new sketch on the top of the base leg. I then
create a circle and replicate it using the circular pattern tool followed but a cut.

![Pattern](../images/ImagW2/GraphicApps/40platebase3.jpg)

![Cut](../images/ImagW2/GraphicApps/40platebase4.jpg)

I then sketched on top again and created a circle to create the plate itself 

![Plate](../images/ImagW2/GraphicApps/40platebase5.jpg)

Here I made a mistake as I did not select the whole plate and where the handy timeline 
tool come into play

![Plate](../images/ImagW2/GraphicApps/40platebase6correction.jpg)

And we are back on track. I wanted to create a downward facing lip in order to provide some water 
protection for the spinning mechanism during the dry cycle.

To do this I am going to draw a sketch of the lip and have it rotate around the plate center axis

Start with sketch

![Plate lip](../images/ImagW2/GraphicApps/40platebase7lip.jpg)

Then used the revolve to create the lip and set it to join the plate base.

![Plate lip](../images/ImagW2/GraphicApps/40platebase8revolve.jpg)

and there you go a first cut at the base plate 

![Plate](../images/ImagW2/GraphicApps/40platebase9.jpg)


Now let do that again in FreeCad




## Code basic set up 

To keep this week in sync with my final project I decided to test a set up for the basic VMS functionality 
replacing the water pump and motor with LED and the sensors with buttons. 

Here is the functionality I was aiming for:



|  Button |  Label | FUnctionality  |
|---|---|---|
| Button 1  | Wash cycle  |   1. Check Lid / Water sensor -> 2. Turn on Water pump and motor for a set time | 
| Button 2  | Dry cycle  |  1. Check Lid -> 2. Turn on motor for a set time |   
|  Button 3 |   Total cycle |  1. Run Wash cycle -> 2. Run Dry cycle | 
|  Sensors |  If either sensor is triggered then stop and turn on error LED |   | 

Here is my updated code:

```c
// Define the pin numbers for the sensors and actuators
const int LED_PIN = 7;
const int WASH_BUTTON_PIN = 11;
const int DRY_BUTTON_PIN = 10;
const int FULL_BUTTON_PIN = 9;
const int WATER_SENSOR_PIN = 2;
const int LID_SENSOR_PIN = 3;
const int DRUM_PIN = 4;
const int WATER_PUMP_PIN = 5;

void setup() {
    Serial.begin(9600);
    pinMode(LED_PIN, OUTPUT);
    pinMode(WASH_BUTTON_PIN, INPUT);
    pinMode(DRY_BUTTON_PIN, INPUT);
    pinMode(FULL_BUTTON_PIN, INPUT);
    pinMode(WATER_SENSOR_PIN, INPUT);
    pinMode(LID_SENSOR_PIN, INPUT);
    pinMode(DRUM_PIN, OUTPUT);
    pinMode(WATER_PUMP_PIN, OUTPUT);
}

void loop() {
    // Wait for the wash button press
    if (digitalRead(WASH_BUTTON_PIN) == HIGH) {
        // Check the water level and lid status
        if (digitalRead(WATER_SENSOR_PIN) == LOW && digitalRead(LID_SENSOR_PIN) == LOW) {
            // Start the wash cycle
            digitalWrite(DRUM_PIN, HIGH);
            digitalWrite(WATER_PUMP_PIN, HIGH);
            delay(600);
            digitalWrite(DRUM_PIN, LOW);
            digitalWrite(WATER_PUMP_PIN, LOW);
              delay(400);
              digitalWrite(WATER_PUMP_PIN, HIGH);
           delay(400);
            digitalWrite(WATER_PUMP_PIN, LOW);
        } else {
            Serial.println("Not enough water or lid is open.");
                        digitalWrite(LED_PIN, HIGH);

        }
    }

    // Wait for the dry button press
    if (digitalRead(DRY_BUTTON_PIN) == HIGH) {
        // Start the slow spin
                if (digitalRead(LID_SENSOR_PIN) == LOW) {

        digitalWrite(DRUM_PIN, HIGH);
        delay(600);

        // Start the fast spin
        digitalWrite(DRUM_PIN, LOW);
        delay(300);
        digitalWrite(DRUM_PIN, HIGH);
        delay(300);
        digitalWrite(DRUM_PIN, LOW);
                }     else {
            Serial.println("lid is open.");
                        digitalWrite(LED_PIN, HIGH);

        }
    }

    // Wait for the full cycle button press
    if (digitalRead(FULL_BUTTON_PIN) == HIGH) {
        // Perform the wash cycle
        if (digitalRead(WATER_SENSOR_PIN) == LOW && digitalRead(LID_SENSOR_PIN) == LOW) {
            // Start the wash cycle
            digitalWrite(DRUM_PIN, HIGH);
            digitalWrite(WATER_PUMP_PIN, HIGH);
            delay(600);
            digitalWrite(DRUM_PIN, LOW);
            digitalWrite(WATER_PUMP_PIN, LOW);
                delay(400);
            digitalWrite(WATER_PUMP_PIN, HIGH);
           delay(400);
            digitalWrite(WATER_PUMP_PIN, LOW);
        } else {
            Serial.println("Not enough water or lid is open.");
             digitalWrite(LED_PIN, HIGH);
            return;
        }

        // Perform the dry cycle
        // Start the slow spin
        if (digitalRead(LID_SENSOR_PIN) == LOW) {
        digitalWrite(DRUM_PIN, HIGH);
        delay(200);

        // Start the fast spin
        digitalWrite(DRUM_PIN, HIGH);
        delay(200);
        digitalWrite(DRUM_PIN, LOW);
        delay(200);
        digitalWrite(DRUM_PIN, HIGH);
        delay(100);
        digitalWrite(DRUM_PIN, LOW);
    
       } else {
            Serial.println("Not enough water or lid is open.");
             digitalWrite(LED_PIN, HIGH);
            return;
        }

    }}
```


Here is the basic circuit I am planning 

![Circuit](../images/ImagW4/Arduino1circuit.jpg)


I followed this diagram (except for the different colored wires) and it went pretty smoothly

Here is the one I built in action:

<iframe width="560" height="315" src="https://www.youtube.com/embed/PIB-q0JtLqo" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe>


